@@ -7,16 +7,42 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2, incorporated herein by reference.
 
+from __future__ import absolute_import
+
 import os
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from .qtcore import (
+    QDir,
+    QTimer,
+    pyqtSignal,
+    pyqtSlot,
+)
+from .qtgui import (
+    QCheckBox,
+    QComboBox,
+    QFileDialog,
+    QFormLayout,
+    QHBoxLayout,
+    QLineEdit,
+    QPushButton,
+    QSizePolicy,
+    QVBoxLayout,
+    QWidget,
+)
 
-from mercurial import cmdutil, commands, hg
+from mercurial import (
+    cmdutil,
+    commands,
+    hg,
+)
 
-from tortoisehg.util import hglib
-from tortoisehg.util.i18n import _
-from tortoisehg.hgqt import cmdcore, cmdui, qtlib
+from ..util import hglib
+from ..util.i18n import _
+from . import (
+    cmdcore,
+    cmdui,
+    qtlib,
+)
 
 def _startrev_available():
     entry = cmdutil.findcmd('clone', commands.table)[1]
@@ -137,10 +163,10 @@ class CloneWidget(cmdui.AbstractCmdWidget):
 
         self.noupdate_chk = QCheckBox(_('Do not update the new working directory'))
         self.pproto_chk = QCheckBox(_('Use pull protocol to copy metadata'))
-        self.uncomp_chk = QCheckBox(_('Use uncompressed transfer'))
+        self.stream_chk = QCheckBox(_('Clone with minimal processing'))
         optbox.addWidget(self.noupdate_chk)
         optbox.addWidget(self.pproto_chk)
-        optbox.addWidget(self.uncomp_chk)
+        optbox.addWidget(self.stream_chk)
 
         self.qclone_chk, self.qclone_txt, self.qclone_btn = \
                 chktext(_('Include patch queue'), btnlabel=_('Browse...'),
@@ -158,6 +184,9 @@ class CloneWidget(cmdui.AbstractCmdWidget):
 
         self.remote_chk, self.remote_text = chktext(_('Remote command:'))
 
+        self.largefiles_chk = QCheckBox(_('Use largefiles'))
+        optbox.addWidget(self.largefiles_chk)
+
         # allow to specify start revision for p4 & svn repos.
         self.startrev_chk, self.startrev_text = chktext(_('Start revision:'),
                                                         stretch=40)
@@ -179,13 +208,14 @@ class CloneWidget(cmdui.AbstractCmdWidget):
         self.rev_text.textChanged.connect(self._composeCommand)
         self.noupdate_chk.toggled.connect(self._composeCommand)
         self.pproto_chk.toggled.connect(self._composeCommand)
-        self.uncomp_chk.toggled.connect(self._composeCommand)
+        self.stream_chk.toggled.connect(self._composeCommand)
         self.qclone_chk.toggled.connect(self._composeCommand)
         self.qclone_txt.textChanged.connect(self._composeCommand)
         self.proxy_chk.toggled.connect(self._composeCommand)
         self.insecure_chk.toggled.connect(self._composeCommand)
         self.remote_chk.toggled.connect(self._composeCommand)
         self.remote_text.textChanged.connect(self._composeCommand)
+        self.largefiles_chk.toggled.connect(self._composeCommand)
         self.startrev_chk.toggled.connect(self._composeCommand)
 
         # prepare to show
@@ -197,7 +227,7 @@ class CloneWidget(cmdui.AbstractCmdWidget):
             self.rev_text.setText(hglib.tounicode(rev))
         self.noupdate_chk.setChecked(bool(opts.get('noupdate')))
         self.pproto_chk.setChecked(bool(opts.get('pull')))
-        self.uncomp_chk.setChecked(bool(opts.get('uncompressed')))
+        self.stream_chk.setChecked(bool(opts.get('stream')))
         self.startrev_chk.setVisible(_startrev_available())
         self.startrev_text.setVisible(_startrev_available())
 
@@ -209,7 +239,7 @@ class CloneWidget(cmdui.AbstractCmdWidget):
             # addItems() can overwrite temporary edit text
             edittext = combo.currentText()
             combo.blockSignals(True)
-            combo.addItems(qs.value(key).toStringList())
+            combo.addItems(qtlib.readStringList(qs, key))
             combo.setCurrentIndex(combo.findText(edittext))
             combo.setEditText(edittext)
             combo.blockSignals(False)
@@ -246,13 +276,14 @@ class CloneWidget(cmdui.AbstractCmdWidget):
     def _composeCommand(self):
         opts = {
             'noupdate': self.noupdate_chk.isChecked(),
-            'uncompressed': self.uncomp_chk.isChecked(),
+            'stream': self.stream_chk.isChecked(),
             'pull': self.pproto_chk.isChecked(),
             'verbose': True,
+            'config': [],
             }
         if (self.ui.config('http_proxy', 'host')
             and not self.proxy_chk.isChecked()):
-            opts['config'] = 'http_proxy.host='
+            opts['config'].append('http_proxy.host=')
         if self.remote_chk.isChecked():
             opts['remotecmd'] = unicode(self.remote_text.text()).strip() or None
         if self.rev_chk.isChecked():
@@ -260,6 +291,8 @@ class CloneWidget(cmdui.AbstractCmdWidget):
         if self.startrev_chk.isChecked():
             opts['startrev'] = (unicode(self.startrev_text.text()).strip()
                                 or None)
+        if self.largefiles_chk.isChecked():
+            opts['config'].append('extensions.largefiles=')
 
         src = self.source()
         dest = self.destination()
