@@ -5,14 +5,43 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2, incorporated herein by reference.
 
+from __future__ import absolute_import
+
 import weakref
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
-from PyQt4.Qsci import QsciScintilla
+from .qsci import (
+    QsciScintilla,
+)
+from .qtcore import (
+    QSettings,
+    Qt,
+    pyqtSignal,
+    pyqtSlot,
+)
+from .qtgui import (
+    QColor,
+    QDialog,
+    QDialogButtonBox,
+    QFont,
+    QHBoxLayout,
+    QLabel,
+    QLayout,
+    QLineEdit,
+    QMessageBox,
+    QProgressBar,
+    QSizePolicy,
+    QStatusBar,
+    QVBoxLayout,
+    QWidget,
+)
 
-from tortoisehg.util.i18n import _
-from tortoisehg.hgqt import cmdcore, qtlib, qscilib
+from ..util import hglib
+from ..util.i18n import _
+from . import (
+    cmdcore,
+    qtlib,
+    qscilib,
+)
 
 def startProgress(topic, status):
     topic, item, pos, total, unit = topic, '...', status, None, ''
@@ -285,15 +314,12 @@ class InteractiveUiHandler(cmdcore.UiHandler):
             return text
 
     def _getChoiceInput(self):
-        parts = self._prompttext.split('$$')
-        msg = parts[0].rstrip(' ')
-        choices = [p.strip(' ') for p in parts[1:]]
-        resps = [p[p.index('&') + 1].lower() for p in choices]
+        msg, choicepairs = hglib.extractchoices(self._prompttext)
         dlg = QMessageBox(QMessageBox.Question, _('TortoiseHg Prompt'), msg,
                           QMessageBox.NoButton, self._parentWidget())
         dlg.setWindowFlags(Qt.Sheet)
         dlg.setWindowModality(Qt.WindowModal)
-        for r, t in zip(resps, choices):
+        for r, t in choicepairs:
             button = dlg.addButton(t, QMessageBox.ActionRole)
             button.response = r
             if r == self._promptdefault:
@@ -531,7 +557,7 @@ class CmdControlDialog(QDialog):
         qs = QSettings()
         qs.beginGroup(self.objectName())
         self.__cmdwidget.readSettings(qs)
-        self.restoreGeometry(qs.value('geom').toByteArray())
+        self.restoreGeometry(qtlib.readByteArray(qs, 'geom'))
         qs.endGroup()
 
     def __writeSettings(self):
