@@ -5,15 +5,29 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2, incorporated herein by reference.
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from __future__ import absolute_import
+
+from .qtcore import (
+    Qt,
+    pyqtSignal,
+    pyqtSlot,
+)
+from .qtgui import (
+    QComboBox,
+    QDialog,
+    QDialogButtonBox,
+    QVBoxLayout,
+)
 
 from mercurial import error
 
-from tortoisehg.util import hglib
-from tortoisehg.util.i18n import _
-from tortoisehg.hgqt import cslist, cmdcore, cmdui
-
+from ..util import hglib
+from ..util.i18n import _
+from . import (
+    cmdcore,
+    cmdui,
+    cslist,
+)
 
 class PerforcePending(QDialog):
     'Dialog for selecting a revision'
