@@ -5,23 +5,44 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2, incorporated herein by reference.
 
+from __future__ import absolute_import
+
 import os
-import stat
 import shutil
+import stat
 
-from mercurial import hg, scmutil, ui
+from .qtcore import (
+    QSettings,
+    QThread,
+    QTimer,
+    Qt,
+    pyqtSignal,
+    pyqtSlot,
+)
+from .qtgui import (
+    QCheckBox,
+    QDialog,
+    QDialogButtonBox,
+    QVBoxLayout,
+    qApp,
+)
 
-from tortoisehg.util import hglib
-from tortoisehg.util.i18n import _, ngettext
-from tortoisehg.hgqt import qtlib, cmdui
+from mercurial import (
+    hg,
+    scmutil,
+)
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from ..util import hglib
+from ..util.i18n import _, ngettext
+from . import (
+    cmdui,
+    qtlib,
+)
 
 class PurgeDialog(QDialog):
 
-    progress = pyqtSignal(QString, object, QString, QString, object)
-    showMessage = pyqtSignal(QString)
+    progress = pyqtSignal(str, object, str, str, object)
+    showMessage = pyqtSignal(str)
 
     def __init__(self, repoagent, parent=None):
         QDialog.__init__(self, parent)
@@ -31,12 +52,12 @@ class PurgeDialog(QDialog):
         self._repoagent = repoagent
 
         layout = QVBoxLayout()
-        layout.setMargin(0)
+        layout.setContentsMargins(0, 0, 0, 0)
         layout.setSpacing(0)
         self.setLayout(layout)
 
         toplayout = QVBoxLayout()
-        toplayout.setMargin(10)
+        toplayout.setContentsMargins(10, 10, 10, 10)
         toplayout.setSpacing(5)
         layout.addLayout(toplayout)
 
@@ -86,7 +107,7 @@ class PurgeDialog(QDialog):
         s = QSettings()
         desktopgeom = qApp.desktop().availableGeometry()
         self.resize(desktopgeom.size() * 0.25)
-        self.restoreGeometry(s.value('purge/geom').toByteArray())
+        self.restoreGeometry(qtlib.readByteArray(s, 'purge/geom'))
 
         self.th = None
         QTimer.singleShot(0, self.checkStatus)
@@ -108,7 +129,7 @@ class PurgeDialog(QDialog):
                     repo.lfstatus = True
                     stat = repo.status(ignored=True, unknown=True)
                     repo.lfstatus = False
-                    trashcan = repo.join('Trashcan')
+                    trashcan = repo.vfs.join('Trashcan')
                     if os.path.isdir(trashcan):
                         trash = os.listdir(trashcan)
                     else:
@@ -195,8 +216,8 @@ class PurgeDialog(QDialog):
             self.reject()
 
 class PurgeThread(QThread):
-    progress = pyqtSignal(QString, object, QString, QString, object)
-    showMessage = pyqtSignal(QString)
+    progress = pyqtSignal(str, object, str, str, object)
+    showMessage = pyqtSignal(str)
 
     def __init__(self, repo, opts, parent):
         super(PurgeThread, self).__init__(parent)
@@ -212,14 +233,14 @@ class PurgeThread(QThread):
             self.showMessage.emit(hglib.tounicode(str(e)))
 
     def purge(self, root, opts):
-        repo = hg.repository(ui.ui(), self.root)
+        repo = hg.repository(hglib.loadui(), self.root)
         keephg = opts['keephg']
         directories = []
         failures = []
 
         if opts['trash']:
             self.showMessage.emit(_('Deleting trash folder...'))
-            trashcan = repo.join('Trashcan')
+            trashcan = repo.vfs.join('Trashcan')
             try:
                 shutil.rmtree(trashcan)
             except EnvironmentError:
