@@ -5,27 +5,76 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-import os
-import sys
+from __future__ import absolute_import
+
 import atexit
+import cgi
+import os
 import posixpath
-import shutil
+import re
 import shlex
+import shutil
+import sip
 import stat
 import subprocess
+import sys
 import tempfile
-import re
-import sip
 import weakref
 
-from mercurial import extensions, error, util
+from .qtcore import (
+    QByteArray,
+    QDir,
+    QEvent,
+    QFile,
+    QObject,
+    QProcess,
+    QSize,
+    QUrl,
+    Qt,
+    pyqtSignal,
+    pyqtSlot,
+)
+from .qtgui import (
+    QApplication,
+    QComboBox,
+    QCommonStyle,
+    QColor,
+    QDesktopServices,
+    QDialog,
+    QFont,
+    QFrame,
+    QHBoxLayout,
+    QIcon,
+    QInputDialog,
+    QKeySequence,
+    QLabel,
+    QLineEdit,
+    QMessageBox,
+    QPainter,
+    QPalette,
+    QPixmap,
+    QPushButton,
+    QShortcut,
+    QSizePolicy,
+    QStyle,
+    QStyleOptionButton,
+    QVBoxLayout,
+    QWidget,
+)
 
-from tortoisehg.util import hglib, paths, editor, terminal
-from tortoisehg.util.i18n import _
-from hgext.color import _styles
+from mercurial import (
+    color,
+    extensions,
+    util,
+)
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from ..util import (
+    editor,
+    hglib,
+    paths,
+    terminal,
+)
+from ..util.i18n import _
 
 try:
     import win32con
@@ -36,16 +85,6 @@ except ImportError:
 # largest allowed size for widget, defined in <src/gui/kernel/qwidget.h>
 QWIDGETSIZE_MAX = (1 << 24) - 1
 
-if PYQT_VERSION < 0x40704:
-    # QObject.sender() goes wrong if connection made in Qt layer.  consider
-    # using QSignalMapper for zero-argument slots instead.
-    def senderSafeSlot(*types, **opts):
-        def deco(func):
-            return func
-        return deco
-else:
-    senderSafeSlot = pyqtSlot
-
 tmproot = None
 def gettempdir():
     global tmproot
@@ -67,7 +106,7 @@ def gettempdir():
 def openhelpcontents(url):
     'Open online help, use local CHM file if available'
     if not url.startswith('http'):
-        fullurl = 'http://tortoisehg.readthedocs.org/en/latest/' + url
+        fullurl = 'https://tortoisehg.readthedocs.org/en/latest/' + url
         # Use local CHM file if it can be found
         if os.name == 'nt' and paths.bin_path:
             chm = os.path.join(paths.bin_path, 'doc', 'TortoiseHg.chm')
@@ -90,7 +129,7 @@ def openlocalurl(path):
         path = unicode(path)
     if os.name == 'nt' and path.startswith('\\\\'):
         # network share, special handling because of qt bug 13359
-        # see http://bugreports.qt.nokia.com/browse/QTBUG-13359
+        # see https://bugreports.qt.io/browse/QTBUG-13359
         qurl = QUrl()
         qurl.setUrl(QDir.toNativeSeparators(path))
     else:
@@ -255,6 +294,62 @@ def openshell(root, reponame, ui=None):
                    _('A terminal shell must be configured'))
 
 
+# 'type' argument of QSettings.value() can't be used because:
+#  a) it appears to be broken before PyQt 4.11.x (#4882)
+#  b) it may raise TypeError if a setting has a value of an unexpected type
+
+def readBool(qs, key, default=False):
+    """Read the specified value from QSettings and coerce into bool"""
+    v = qs.value(key, default)
+    if isinstance(v, basestring):
+        # qvariant.cpp:qt_convertToBool()
+        return not (v == '0' or v == 'false' or v == '')
+    return bool(v)
+
+def readByteArray(qs, key, default=b''):
+    """Read the specified value from QSettings and coerce into QByteArray"""
+    v = qs.value(key, default)
+    if v is None:
+        return QByteArray(default)
+    try:
+        return QByteArray(v)
+    except TypeError:
+        return QByteArray(default)
+
+def readInt(qs, key, default=0):
+    """Read the specified value from QSettings and coerce into int"""
+    v = qs.value(key, default)
+    if v is None:
+        return int(default)
+    try:
+        return int(v)
+    except (TypeError, ValueError):
+        return int(default)
+
+def readString(qs, key, default=''):
+    """Read the specified value from QSettings and coerce into string"""
+    v = qs.value(key, default)
+    if v is None:
+        return unicode(default)
+    try:
+        return unicode(v)
+    except ValueError:
+        return unicode(default)
+
+def readStringList(qs, key, default=()):
+    """Read the specified value from QSettings and coerce into string list"""
+    v = qs.value(key, default)
+    if v is None:
+        return list(default)
+    if isinstance(v, basestring):
+        # qvariant.cpp:convert()
+        return [v]
+    try:
+        return [unicode(e) for e in v]
+    except (TypeError, ValueError):
+        return list(default)
+
+
 def isDarkTheme(palette=None):
     """True if white-on-black color scheme is preferable"""
     if not palette:
@@ -266,6 +361,9 @@ def isDarkTheme(palette=None):
 # set of _effects, since we convert color effect names to font style
 # effect programatically.
 
+# TODO: update ui._styles instead of color._defaultstyles
+_styles = color._defaultstyles
+
 _effects = {
     'bold': 'font-weight: bold',
     'italic': 'font-style: italic',
@@ -315,8 +413,8 @@ def configstyles(ui):
         cfgeffects = ui.configlist('thg-color', status)
         _styles[status] = ' '.join(cfgeffects)
 
-# See http://doc.trolltech.com/4.2/richtext-html-subset.html
-# and http://www.w3.org/TR/SVG/types.html#ColorKeywords
+# See https://doc.qt.io/qt-4.8/richtext-html-subset.html
+# and https://www.w3.org/TR/SVG/types.html#ColorKeywords
 
 def geteffect(labels):
     'map labels like "log.date" to Qt font styles'
@@ -379,7 +477,7 @@ def markup(msg, **styles):
         style[name] = value
     style = ';'.join(['%s: %s' % t for t in style.items()])
     msg = hglib.tounicode(msg)
-    msg = Qt.escape(msg)
+    msg = cgi.escape(msg)
     msg = msg.replace('\n', '<br />')
     return u'<span style="%s">%s</span>' % (style, msg)
 
@@ -405,6 +503,8 @@ def descriptionhtmlizer(ui):
      u'http://example.com:8000/foo?bar=baz&amp;bax#blah</a>')
     >>> htmlize('https://example/')
     u'<a href="https://example/">https://example/</a>'
+    >>> htmlize('<https://example/>')
+    u'&lt;<a href="https://example/">https://example/</a>&gt;'
 
     issue links:
     >>> u.setconfig('tortoisehg', 'issue.regex', r'#(\\d+)\\b')
@@ -439,8 +539,8 @@ def descriptionhtmlizer(ui):
     regexp = r'%s|%s' % (csmatch, httpmatch)
     bodyre = re.compile(regexp)
 
-    issuematch = ui.config('tortoisehg', 'issue.regex')
-    issuerepl = ui.config('tortoisehg', 'issue.link')
+    issuematch = hglib.tounicode(ui.config('tortoisehg', 'issue.regex'))
+    issuerepl = hglib.tounicode(ui.config('tortoisehg', 'issue.link'))
     if issuematch and issuerepl:
         regexp += '|(%s)' % issuematch
         try:
@@ -450,35 +550,36 @@ def descriptionhtmlizer(ui):
 
     def htmlize(desc):
         """Mark up ctx.description() [localstr] as an HTML [unicode]"""
-        desc = unicode(Qt.escape(hglib.tounicode(desc)))
+        desc = hglib.tounicode(desc)
 
         buf = ''
         pos = 0
         for m in bodyre.finditer(desc):
             a, b = m.span()
             if a >= pos:
-                buf += desc[pos:a]
+                buf += cgi.escape(desc[pos:a])
                 pos = b
             groups = m.groups()
             if groups[0]:
-                cslink = groups[0]
+                cslink = cgi.escape(groups[0])
                 buf += '<a href="cset:%s">%s</a>' % (cslink, cslink)
             if groups[1]:
-                urllink = groups[1]
+                urllink = cgi.escape(groups[1])
                 buf += '<a href="%s">%s</a>' % (urllink, urllink)
             if len(groups) > 4 and groups[4]:
-                issue = groups[4]
+                issue = cgi.escape(groups[4])
                 issueparams = groups[4:]
                 try:
                     link = re.sub(r'\{(\d+)\}',
                                   lambda m: issueparams[int(m.group(1))],
                                   issuerepl)
+                    link = cgi.escape(link)
                     buf += '<a href="%s">%s</a>' % (link, issue)
                 except IndexError:
                     buf += issue
 
         if pos < len(desc):
-            buf += desc[pos:]
+            buf += cgi.escape(desc[pos:])
 
         return buf
 
@@ -509,7 +610,7 @@ def _findcustomicon(name):
             return QIcon(path)
     return None
 
-# http://standards.freedesktop.org/icon-theme-spec/icon-theme-spec-latest.html
+# https://specifications.freedesktop.org/icon-theme-spec/icon-theme-spec-latest.html
 _SCALABLE_ICON_PATHS = [(QSize(), 'scalable/actions', '.svg'),
                         (QSize(), 'scalable/apps', '.svg'),
                         (QSize(), 'scalable/status', '.svg'),
@@ -590,7 +691,7 @@ def getcheckboxpixmap(state, bgcolor, widget):
     option = QStyleOptionButton()
     style = QApplication.style()
     option.initFrom(widget)
-    option.rect = style.subElementRect(style.SE_CheckBoxIndicator, option)
+    option.rect = style.subElementRect(style.SE_CheckBoxIndicator, option, None)
     option.rect.moveTo(1, 1)
     option.state |= state
     style.drawPrimitive(style.PE_IndicatorCheckBox, option, painter)
@@ -602,14 +703,19 @@ def getcheckboxpixmap(state, bgcolor, widget):
 # To fix that we let users force tortoishg to use smaller icons by setting a
 # THG_RETINA environment variable to True (or any value that mercurial parses
 # as True.
-IS_RETINA = False
-if sys.platform == 'darwin':
-    IS_RETINA = util.parsebool(os.environ.get('THG_RETINA', '0'))
-
+# Whereas on Linux, Qt4 has no support for high dpi displays at all causing
+# icons to be rendered unusably small. The workaround for that is to render
+# the icons at double the normal size.
+# TODO: Remove this hack after upgrading to Qt5.
+IS_RETINA = util.parsebool(os.environ.get('THG_RETINA', '0'))
 
 def _fixIconSizeForRetinaDisplay(s):
-    if IS_RETINA and s > 1:
-        s /= 2
+    if IS_RETINA:
+        if sys.platform == 'darwin':
+            if s > 1:
+                s /= 2
+        elif sys.platform == 'linux2':
+            s *= 2
     return s
 
 def smallIconSize():
@@ -653,7 +759,6 @@ class ThgFont(QObject):
 _fontdefaults = {
     'fontcomment': 'monospace,10',
     'fontdiff': 'monospace,10',
-    'fontlist': 'sans,9',
     'fontlog': 'monospace,10',
     'fontoutputlog': 'sans,8'
 }
@@ -677,7 +782,7 @@ def CommonMsgBox(icon, title, main, text='', buttons=QMessageBox.Ok,
     msg.setWindowTitle(title)
     msg.setStandardButtons(buttons)
     for button_id, label in labels:
-        msg.setButtonText(button_id, label)
+        msg.button(button_id).setText(label)
     if defaultbutton:
         msg.setDefaultButton(defaultbutton)
     msg.setText('<b>%s</b>' % main)
@@ -794,6 +899,7 @@ class BadCompletionBlocker(QObject):
     replaces the edit text by the current completion on enter key pressed.
     This is wrong in the following scenario:
 
+    >>> from .qtgui import QKeyEvent
     >>> combo = QComboBox(editable=True)
     >>> combo.addItem('history value')
     >>> combo.setEditText('initial value')
@@ -896,7 +1002,7 @@ class PMButton(QPushButton):
         self.setIcon(icon)
 
     def is_expanded(self):
-        return self.icon().serialNumber() == self.minus.serialNumber()
+        return self.icon().cacheKey() == self.minus.cacheKey()
 
     def is_collapsed(self):
         return not self.is_expanded()
@@ -1080,6 +1186,7 @@ class DialogKeeper(QObject):
 
     closed dialog will be deleted:
 
+    >>> from .qtcore import QEventLoop, QTimer
     >>> def processDeferredDeletion():
     ...     loop = QEventLoop()
     ...     QTimer.singleShot(0, loop.quit)
@@ -1248,20 +1355,6 @@ class Spacer(QWidget):
     def sizeHint(self):
         return QSize(self.width, self.height)
 
-def _configuredusername(ui):
-    # need to check the existence before calling ui.username(); otherwise it
-    # may fall back to the system default.
-    if (not os.environ.get('HGUSER')
-        and not ui.config('ui', ['username', 'user'])
-        and not os.environ.get('EMAIL')):
-        return None
-    try:
-        if ui.configbool('ui', 'askusername'):
-            ui.setconfig('ui', 'askusername', False)
-        return ui.username()
-    except error.Abort:
-        return None
-
 def getCurrentUsername(widget, repo, opts=None):
     if opts:
         # 1. Override has highest priority
@@ -1270,7 +1363,7 @@ def getCurrentUsername(widget, repo, opts=None):
             return user
 
     # 2. Read from repository
-    user = _configuredusername(repo.ui)
+    user = hglib.configuredusername(repo.ui)
     if user:
         return user
 
@@ -1282,7 +1375,7 @@ def getCurrentUsername(widget, repo, opts=None):
     dlg = SettingsDialog(False, focus='ui.username')
     dlg.exec_()
     repo.invalidateui()
-    return _configuredusername(repo.ui)
+    return hglib.configuredusername(repo.ui)
 
 class _EncodingSafeInputDialog(QInputDialog):
     def accept(self):
