@@ -5,16 +5,50 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
+from __future__ import absolute_import
+
 import os
 
-from mercurial import commands, hg, ui, util
+from .qtcore import (
+    QFileSystemWatcher,
+    QModelIndex,
+    QPoint,
+    QSettings,
+    QTimer,
+    Qt,
+    pyqtSignal,
+    pyqtSlot,
+)
+from .qtgui import (
+    QAbstractItemView,
+    QAction,
+    QApplication,
+    QDockWidget,
+    QFileDialog,
+    QFontMetrics,
+    QFrame,
+    QMenu,
+    QMessageBox,
+    QTreeView,
+    QVBoxLayout,
+)
 
-from tortoisehg.util import hglib, paths
-from tortoisehg.util.i18n import _
-from tortoisehg.hgqt import qtlib, repotreemodel, settings
+from mercurial import (
+    commands,
+    hg,
+    util,
+)
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from ..util import (
+    hglib,
+    paths,
+)
+from ..util.i18n import _
+from . import (
+    qtlib,
+    repotreemodel,
+    settings,
+)
 
 def settingsfilename():
     """Return path to thg-reporegistry.xml as unicode"""
@@ -40,13 +74,13 @@ class RepoTreeView(QTreeView):
         self.setMouseTracking(True)
 
         # enable drag and drop
-        # (see http://doc.qt.nokia.com/4.6/model-view-dnd.html)
+        # see
+        # https://doc.qt.io/qt-4.8/model-view-programming.html#using-drag-and-drop-with-item-views
         self.setDragEnabled(True)
         self.setAcceptDrops(True)
         self.setAutoScroll(True)
         self.setDragDropMode(QAbstractItemView.DragDrop)
-        if PYQT_VERSION >= 0x40700:
-            self.setDefaultDropAction(Qt.MoveAction)
+        self.setDefaultDropAction(Qt.MoveAction)
         self.setDropIndicatorShown(True)
         self.setEditTriggers(QAbstractItemView.DoubleClicked
                              | QAbstractItemView.EditKeyPressed)
@@ -160,7 +194,7 @@ class RepoTreeView(QTreeView):
 
         if event.buttons() == Qt.NoButton:
             # Bail out early to avoid tripping over this bug:
-            # http://bugreports.qt.nokia.com/browse/QTBUG-10180
+            # https://bugreports.qt.io/browse/QTBUG-10180
             return
         super(RepoTreeView, self).mouseMoveEvent(event)
 
@@ -260,7 +294,7 @@ class RepoRegistryView(QDockWidget):
         s = QSettings()
         s.beginGroup('Workbench')  # for compatibility with old release
         for key, action in self._settingactions.iteritems():
-            action.setChecked(s.value(key, defaultmap[key]).toBool())
+            action.setChecked(qtlib.readBool(s, key, defaultmap[key]))
         s.endGroup()
 
     def _saveSettings(self):
@@ -303,7 +337,7 @@ class RepoRegistryView(QDockWidget):
 
     def settingActions(self):
         return sorted(self._settingactions.itervalues(),
-                      key=lambda a: a.data().toInt())
+                      key=lambda a: a.data())
 
     def _isSettingEnabled(self, key):
         return self._settingactions[key].isChecked()
@@ -354,7 +388,7 @@ class RepoRegistryView(QDockWidget):
 
     def _readExpandedState(self, s):
         model = self.tview.model()
-        for path in s.value('expanded').toStringList():
+        for path in qtlib.readStringList(s, 'expanded'):
             self.tview.expand(model.indexFromItemPath(path))
 
     def _writeExpandedState(self, s):
@@ -572,7 +606,8 @@ class RepoRegistryView(QDockWidget):
 
                 # Is is already on the selected repository substate list?
                 try:
-                    repo = hg.repository(ui.ui(), hglib.fromunicode(root))
+                    repo = hg.repository(hglib.loadui(),
+                                         hglib.fromunicode(root))
                 except:
                     qtlib.WarningMsgBox(_('Cannot open repository'),
                         _('The selected repository:<br><br>%s<br><br>'
@@ -591,7 +626,7 @@ class RepoRegistryView(QDockWidget):
                     hasHgsub = os.path.exists(repo.wjoin('.hgsub'))
                     if hasHgsub:
                         try:
-                            fsub = repo.wopener('.hgsub', 'r')
+                            fsub = repo.wvfs('.hgsub', 'r')
                             lines = fsub.readlines()
                             fsub.close()
                         except:
@@ -630,11 +665,12 @@ class RepoRegistryView(QDockWidget):
 
                     # and update the .hgsub file
                     try:
-                        fsub = repo.wopener('.hgsub', 'w')
+                        fsub = repo.wvfs('.hgsub', 'w')
                         fsub.write(linesep.join(lines) + linesep)
                         fsub.close()
                         if not hasHgsub:
-                            commands.add(ui.ui(), repo, repo.wjoin('.hgsub'))
+                            commands.add(hglib.loadui(),
+                                         repo, repo.wjoin('.hgsub'))
                         qtlib.InfoMsgBox(
                             _('Subrepo added to .hgsub file'),
                             _('The selected subrepo:<br><br><i>%s</i><br><br>'
@@ -808,7 +844,8 @@ class RepoRegistryView(QDockWidget):
         model = self.tview.model()
         index = self.tview.currentIndex()
         ip = index.internalPointer()
-        repo = hg.repository(ui.ui(), hglib.fromunicode(model.repoRoot(index)))
+        repo = hg.repository(hglib.loadui(),
+                             hglib.fromunicode(model.repoRoot(index)))
         ctx = repo['.']
         wfile = '.hgsub'
         if wfile not in ctx:
