@@ -6,17 +6,36 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
+from __future__ import absolute_import
+
 import os
 
-from PyQt4.QtCore import Qt, SIGNAL, SLOT, pyqtSignal, pyqtSlot
-from PyQt4.QtCore import QObject, QPoint, QSignalMapper
-from PyQt4.QtGui import *
+from .qtcore import (
+    QPoint,
+    QSignalMapper,
+    Qt,
+    pyqtSignal,
+    pyqtSlot,
+)
+from .qtgui import (
+    QAction,
+    QActionGroup,
+    QMenu,
+    QStackedLayout,
+    QTabBar,
+    QVBoxLayout,
+    QWidget,
+)
 
 from mercurial import error
 
-from tortoisehg.util import hglib
-from tortoisehg.util.i18n import _
-from tortoisehg.hgqt import cmdcore, qtlib, repowidget
+from ..util import hglib
+from ..util.i18n import _
+from . import (
+    cmdcore,
+    qtlib,
+    repowidget,
+)
 
 class _TabBar(QTabBar):
 
@@ -37,6 +56,7 @@ class RepoTabWidget(QWidget):
     makeLogVisible = pyqtSignal(bool)
     progressReceived = pyqtSignal(str, cmdcore.ProgressMessage)
     showMessageSignal = pyqtSignal(str)
+    taskTabVisibilityChanged = pyqtSignal(bool)
     toolbarVisibilityChanged = pyqtSignal(bool)
 
     # look-up of tab-index and stack-index:
@@ -75,6 +95,9 @@ class RepoTabWidget(QWidget):
         tabbar.setContextMenuPolicy(Qt.CustomContextMenu)
         tabbar.customContextMenuRequested.connect(self._onTabMenuRequested)
 
+        self._initTabSwitchActions()
+        tabbar.tabMoved.connect(self._updateTabSwitchActions)
+
         self._stack = QStackedLayout()
         vbox.addLayout(self._stack, 1)
 
@@ -87,6 +110,8 @@ class RepoTabWidget(QWidget):
         self._titlemapper = QSignalMapper(self)
         self._titlemapper.mapped[QWidget].connect(self._updateTitle)
 
+        self._updateTabSwitchActions()
+
     def openRepo(self, root, bundle=None):
         """Open the specified repository in new tab"""
         rw = self._createRepoWidget(root, bundle)
@@ -101,6 +126,7 @@ class RepoTabWidget(QWidget):
         tabbar.setTabToolTip(index, rw.repoRootPath())
         self.setCurrentIndex(index)
         tabbar.blockSignals(False)
+        self._updateTabSwitchActions()
         self._updateTabVisibility()
         self._onCurrentTabChanged(index)
         return True
@@ -114,6 +140,7 @@ class RepoTabWidget(QWidget):
             index = tabbar.insertTab(index, os.path.basename(root))
             tabbar.setTabToolTip(index, root)
         tabbar.blockSignals(False)
+        self._updateTabSwitchActions()
         self._updateTabVisibility()
         # must call _onCurrentTabChanged() appropriately
 
@@ -166,6 +193,7 @@ class RepoTabWidget(QWidget):
                 self._repomanager.releaseRepoAgent(rw.repoRootPath())
                 rw.deleteLater()
         self._tabbar.blockSignals(False)
+        self._updateTabSwitchActions()
         self._updateTabVisibility()
         if tabchange:
             self._onCurrentTabChanged(self.currentIndex())
@@ -245,6 +273,37 @@ class RepoTabWidget(QWidget):
         if origindex != self.currentIndex():
             self._onCurrentTabChanged(self.currentIndex())
 
+    def tabSwitchActions(self):
+        """List of actions to switch current tabs; should be registered to
+        the main window or menu"""
+        return self._swactions.actions()
+
+    def _initTabSwitchActions(self):
+        self._swactions = QActionGroup(self)
+        self._swactions.triggered.connect(self._setCurrentTabByAction)
+        for i in xrange(9):
+            a = self._swactions.addAction('')
+            a.setCheckable(True)
+            a.setData(i)
+            a.setShortcut('Ctrl+%d' % (i + 1))
+
+    @pyqtSlot()
+    def _updateTabSwitchActions(self):
+        self._swactions.setVisible(self._tabbar.count() > 1)
+        if not self._swactions.isVisible():
+            return
+        for i, a in enumerate(self._swactions.actions()):
+            a.setVisible(i < self.count())
+            if not a.isVisible():
+                continue
+            a.setChecked(i == self.currentIndex())
+            a.setText(self._tabbar.tabText(i))
+
+    @pyqtSlot(QAction)
+    def _setCurrentTabByAction(self, action):
+        index = action.data()
+        self.setCurrentIndex(index)
+
     def currentRepoRootPath(self):
         return self.repoRootPath(self.currentIndex())
 
@@ -278,6 +337,7 @@ class RepoTabWidget(QWidget):
             rw = self._createRepoWidget(self.repoRootPath(index))
             if not rw:
                 tabbar.removeTab(index)  # may reenter
+                self._updateTabSwitchActions()
                 self._updateTabVisibility()
                 return
             tabbar.setTabData(index, rw)
@@ -286,6 +346,7 @@ class RepoTabWidget(QWidget):
             tabbar.setTabToolTip(index, rw.repoRootPath())
         if rw:
             self._stack.setCurrentWidget(rw)
+        self._updateTabSwitchActions()
 
         prevpath = self._curpath
         self._curpath = self.repoRootPath(index)
@@ -315,7 +376,7 @@ class RepoTabWidget(QWidget):
         return -1
 
     def _widget(self, index):
-        return self._tabbar.tabData(index).toPyObject()
+        return self._tabbar.tabData(index)
 
     def _createRepoWidget(self, root, bundle=None):
         try:
@@ -331,18 +392,16 @@ class RepoTabWidget(QWidget):
         rw.repoLinkClicked.connect(self._openLinkedRepo)
         rw.revisionSelected.connect(self.historyChanged)
         rw.showMessageSignal.connect(self.showMessageSignal)
+        rw.taskTabVisibilityChanged.connect(self.taskTabVisibilityChanged)
         rw.toolbarVisibilityChanged.connect(self.toolbarVisibilityChanged)
-        # PyQt 4.6 cannot find compatible signal by new-style connection
-        QObject.connect(rw, SIGNAL('busyIconChanged()'),
-                        self._iconmapper, SLOT('map()'))
+        rw.busyIconChanged.connect(self._iconmapper.map)
         self._iconmapper.setMapping(rw, rw)
-        QObject.connect(rw, SIGNAL('titleChanged(QString)'),
-                        self._titlemapper, SLOT('map()'))
+        rw.titleChanged.connect(self._titlemapper.map)
         self._titlemapper.setMapping(rw, rw)
         self._stack.addWidget(rw)
         return rw
 
-    @qtlib.senderSafeSlot(str, object, str, str, object)
+    @pyqtSlot(str, object, str, str, object)
     def _mapProgressReceived(self, topic, pos, item, unit, total):
         rw = self.sender()
         assert isinstance(rw, repowidget.RepoWidget)
@@ -366,15 +425,16 @@ class RepoTabWidget(QWidget):
                 # case, the user is going to commit changes to this repo.
                 rw.switchToNamedTaskTab('commit')
 
-    @pyqtSlot(QWidget)
+    @pyqtSlot('QWidget*')
     def _updateIcon(self, rw):
         index = self._indexOf(rw)
         self._tabbar.setTabIcon(index, rw.busyIcon())
 
-    @pyqtSlot(QWidget)
+    @pyqtSlot('QWidget*')
     def _updateTitle(self, rw):
         index = self._indexOf(rw)
         self._tabbar.setTabText(index, rw.title())
+        self._updateTabSwitchActions()
         if index == self.currentIndex():
             self.currentTitleChanged.emit()
 
