@@ -5,14 +5,33 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2, incorporated herein by reference.
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from __future__ import absolute_import
 
-from mercurial import util
+from .qtcore import (
+    Qt,
+    pyqtSlot,
+)
+from .qtgui import (
+    QCheckBox,
+    QDialog,
+    QDialogButtonBox,
+    QFormLayout,
+    QFrame,
+    QHBoxLayout,
+    QLabel,
+    QLayout,
+    QLineEdit,
+    QSizePolicy,
+    QVBoxLayout,
+    QWidget,
+)
 
-from tortoisehg.util import hglib
-from tortoisehg.util.i18n import _
-from tortoisehg.hgqt import cmdcore, qtlib
+from ..util import hglib
+from ..util.i18n import _
+from . import (
+    cmdcore,
+    qtlib,
+)
 
 class SignDialog(QDialog):
 
@@ -120,11 +139,10 @@ class SignDialog(QDialog):
             self.customMessageToggle(False)
         self.keyLineEdit.setFocus()
 
-        expanded = util.any([self.replaceCheckBox.isChecked(),
-                  self.localCheckBox.isChecked(),
-                  self.nocommitCheckBox.isChecked(),
-                  self.customCheckBox.isChecked()
-                  ])
+        expanded = any([self.replaceCheckBox.isChecked(),
+                        self.localCheckBox.isChecked(),
+                        self.nocommitCheckBox.isChecked(),
+                        self.customCheckBox.isChecked()])
         expander.set_expanded(expanded)
         self.show_options(expanded)
 
