@@ -6,18 +6,76 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-import os, re
+from __future__ import absolute_import
+
+import os
+import re
 import tempfile
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from .qtcore import (
+    QAbstractTableModel,
+    QDir,
+    QMimeData,
+    QModelIndex,
+    QPoint,
+    QSettings,
+    QTimer,
+    QUrl,
+    Qt,
+    pyqtSignal,
+    pyqtSlot,
+)
+from .qtgui import (
+    QAction,
+    QApplication,
+    QCheckBox,
+    QComboBox,
+    QDesktopServices,
+    QDialog,
+    QDialogButtonBox,
+    QFileDialog,
+    QFormLayout,
+    QFrame,
+    QGroupBox,
+    QHBoxLayout,
+    QKeySequence,
+    QLabel,
+    QLineEdit,
+    QMenu,
+    QPushButton,
+    QRadioButton,
+    QSizePolicy,
+    QStackedLayout,
+    QStyle,
+    QToolBar,
+    QTreeView,
+    QVBoxLayout,
+    QWidget,
+)
 
-from mercurial import hg, util, scmutil, httpconnection
+from mercurial import (
+    hg,
+    httpconnection,
+    util,
+)
 
-from tortoisehg.util import hglib, paths, wconfig
-from tortoisehg.util.i18n import _
-from tortoisehg.hgqt import cmdcore, cmdui, qtlib, thgrepo
-from tortoisehg.hgqt import bookmark, hgrcutil, hgemail, rebase, resolve
+from ..util import (
+    hglib,
+    paths,
+    wconfig,
+)
+from ..util.i18n import _
+from . import (
+    bookmark,
+    cmdcore,
+    cmdui,
+    hgemail,
+    hgrcutil,
+    qtlib,
+    rebase,
+    resolve,
+    thgrepo,
+)
 
 def parseurl(url):
     assert type(url) == unicode
@@ -64,12 +122,12 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
 
         s = QSettings()
         for opt in ('force', 'new-branch', 'noproxy', 'debug', 'mq'):
-            val = s.value('sync/' + opt, None).toBool()
+            val = qtlib.readBool(s, 'sync/' + opt)
             if val:
                 if opt != 'mq' or 'mq' in self.repo.extensions():
                     self.opts[opt] = val
         for opt in ('remotecmd', 'branch'):
-            val = hglib.fromunicode(s.value('sync/' + opt, None).toString())
+            val = hglib.fromunicode(qtlib.readString(s, 'sync/' + opt))
             if val:
                 self.opts[opt] = val
 
@@ -306,7 +364,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
     def reload(self):
         # Refresh configured paths
         self.paths = {}
-        fn = self.repo.join('hgrc')
+        fn = self.repo.vfs.join('hgrc')
         fn, cfg = hgrcutil.loadIniFile([fn], self)
         if 'paths' in cfg:
             for alias in cfg['paths']:
@@ -385,7 +443,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
 
     def pathSelected(self, index):
         aliasindex = index.sibling(index.row(), 0)
-        alias = aliasindex.data(Qt.DisplayRole).toString()
+        alias = aliasindex.data(Qt.DisplayRole)
         self.curalias = hglib.fromunicode(alias)
         path = index.model().realUrl(index)
         self.setEditUrl(hglib.tounicode(path))
@@ -579,7 +637,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
             if self.targetcheckbox.isChecked():
                 idx = self.targetcombo.currentIndex()
                 if idx != -1:
-                    args = self.targetcombo.itemData(idx).toPyObject()
+                    args = self.targetcombo.itemData(idx)
                     if args[0][2:] not in details:
                         args = ('--rev',) + args[1:]
                     cmdline += args
@@ -757,7 +815,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         self.pullCompleted.emit()
         # handle file conflicts during rebase
         if self.cachedpp in ('rebase', 'updateorrebase'):
-            if os.path.exists(self.repo.join('rebasestate')):
+            if os.path.exists(self.repo.vfs.join('rebasestate')):
                 dlg = rebase.RebaseDialog(self._repoagent, self)
                 dlg.exec_()
                 return
@@ -976,7 +1034,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         caption = _("Select bundle file")
         _FILE_FILTER = ';;'.join([_("Bundle files (*.hg)"),
                                   _("All files (*)")])
-        bundlefile = QFileDialog.getOpenFileName(
+        bundlefile, _filter = QFileDialog.getOpenFileName(
             self, caption, hglib.tounicode(self.repo.root), _FILE_FILTER)
         if bundlefile:
             # Set the pull source to the selected bundle file
@@ -988,7 +1046,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
     @pyqtSlot(str)
     def removeAlias(self, alias):
         alias = hglib.fromunicode(alias)
-        fn = self.repo.join('hgrc')
+        fn = self.repo.vfs.join('hgrc')
         fn, cfg = hgrcutil.loadIniFile([fn], self)
         if not hasattr(cfg, 'write'):
             qtlib.WarningMsgBox(_('Unable to remove URL'),
@@ -1090,7 +1148,7 @@ class PostPullDialog(QDialog):
                     if chk.isChecked()).next()
 
     def accept(self):
-        path = self.repo.join('hgrc')
+        path = self.repo.vfs.join('hgrc')
         fn, cfg = hgrcutil.loadIniFile([path], self)
         if not hasattr(cfg, 'write'):
             qtlib.WarningMsgBox(_('Unable to save post pull operation'),
@@ -1154,7 +1212,7 @@ class SaveDialog(QDialog):
         s = QSettings()
         self.updatesubpaths = QCheckBox(_('Update subrepo paths'))
         self.updatesubpaths.setChecked(
-            s.value('sync/updatesubpaths', True).toBool())
+            qtlib.readBool(s, 'sync/updatesubpaths', True))
         self.updatesubpaths.setToolTip(
             _('Update or create a path alias called \'%s\' on all subrepos, '
               'using this URL as the base URL, '
@@ -1174,7 +1232,7 @@ class SaveDialog(QDialog):
         self._updateUi()
 
     def savePath(self, repo, alias, path, confirm=True):
-        fn = repo.join('hgrc')
+        fn = repo.vfs.join('hgrc')
         fn, cfg = hgrcutil.loadIniFile([fn], self)
         if not hasattr(cfg, 'write'):
             qtlib.WarningMsgBox(_('Unable to save an URL'),
@@ -1305,7 +1363,11 @@ class SecureDialog(QDialog):
         self.insecureradio = QRadioButton(
             _('No host validation, but still encrypted (bad)'))
         hbox = QHBoxLayout()
-        fprint = repo.ui.config('hostfingerprints', u.host, '')
+        fprint = repo.ui.config('hostsecurity', u.host + ':fingerprints', '')
+        if not fprint:
+            fprint = repo.ui.config('hostfingerprints', u.host, '')
+            if fprint:
+                fprint = 'sha1:' + fprint
         self.fprintentry = le = QLineEdit(fprint)
         self.fprintradio.toggled.connect(self.fprintentry.setEnabled)
         self.fprintentry.setEnabled(False)
@@ -1425,7 +1487,7 @@ are expanded in the filename.'''))
     @pyqtSlot()
     def _browseClientKey(self):
         e = self._authentries['key']
-        n = QFileDialog.getOpenFileName(
+        n, _f = QFileDialog.getOpenFileName(
             self, _('Select User Certificate Key File'), e.text(),
             ';;'.join([_('PEM files (*.pem *.key)'), _('All files (*)')]))
         if n:
@@ -1434,14 +1496,14 @@ are expanded in the filename.'''))
     @pyqtSlot()
     def _browseClientCert(self):
         e = self._authentries['cert']
-        n = QFileDialog.getOpenFileName(
+        n, _f = QFileDialog.getOpenFileName(
             self, _('Select User Certificate Chain File'), e.text(),
             ';;'.join([_('PEM files (*.pem *.crt *.cer)'), _('All files (*)')]))
         if n:
             e.setText(n)
 
     def accept(self):
-        path = scmutil.userrcpath()
+        path = hglib.userrcpath()
         fn, cfg = hgrcutil.loadIniFile(path, self)
         if not hasattr(cfg, 'write'):
             qtlib.WarningMsgBox(_('Unable to save authentication'),
@@ -1465,11 +1527,11 @@ are expanded in the filename.'''))
         else:
             fprint = None
             insecure = '1'
-        setorclear('hostfingerprints', self.host, fprint)
+        setorclear('hostsecurity', '%s:fingerprints' % self.host, fprint)
         setorclear('insecurehosts', self.host, insecure)
 
         e = self._protocolcombo
-        protocol = hglib.fromunicode(e.itemData(e.currentIndex()).toString())
+        protocol = hglib.fromunicode(e.itemData(e.currentIndex()))
         setorclear('hostsecurity', '%s:minimumprotocol' % self.host, protocol)
 
         cfg.set('auth', self.alias+'.prefix', self.host)
@@ -1505,8 +1567,8 @@ class PathsTree(QTreeView):
 
     def contextMenuEvent(self, event):
         for index in self.selectedRows():
-            alias = index.data(Qt.DisplayRole).toString()
-            url = index.sibling(index.row(), 1).data(Qt.DisplayRole).toString()
+            alias = index.data(Qt.DisplayRole)
+            url = index.sibling(index.row(), 1).data(Qt.DisplayRole)
             self.menuRequest.emit(event.globalPos(), url, alias, self.editable)
             return
 
@@ -1518,7 +1580,7 @@ class PathsTree(QTreeView):
 
     def deleteSelected(self):
         for index in self.selectedRows():
-            alias = index.data(Qt.DisplayRole).toString()
+            alias = index.data(Qt.DisplayRole)
             r = qtlib.QuestionMsgBox(_('Confirm path delete'),
                     _('Delete %s from your repo configuration file?') % alias,
                     parent=self)
@@ -1551,16 +1613,16 @@ class PathsModel(QAbstractTableModel):
 
     def data(self, index, role=Qt.DisplayRole):
         if not index.isValid():
-            return QVariant()
+            return None
         if role == Qt.DisplayRole:
-            return QVariant(self.rows[index.row()][index.column()])
-        return QVariant()
+            return self.rows[index.row()][index.column()]
+        return None
 
     def headerData(self, col, orientation, role=Qt.DisplayRole):
         if role != Qt.DisplayRole or orientation != Qt.Horizontal:
-            return QVariant()
+            return None
         else:
-            return QVariant(self.headers[col])
+            return self.headers[col]
 
     def mimeData(self, indexes):
         urls = []
